@@ -326,26 +326,26 @@ int QmVocDocument::open( const QUrl& url )
 
             case Vokabeln: {
                 qDebug() << "Reading Vokabeln document...";
-                qCritical ("Vokabeln document not yet supported...");
-                errorMessage = "Vokabeln document not yet supported...";
-//                 QmVocVokabelnReader vokabelnReader( f );
-//                 d->m_url.setFileName( "Untitled" );
-//                 read = vokabelnReader.readDoc( this );
-//                 if ( !read ) {
-//                     errorMessage = vokabelnReader.errorMessage();
-//                 }
+//                qCritical ("Vokabeln document not yet supported...");
+//                errorMessage = "Vokabeln document not yet supported...";
+                 QmVocVokabelnReader vokabelnReader( f );
+                 // d->m_url.setFileName( "Untitled" );
+                 read = vokabelnReader.readDoc( this );
+                 if ( !read ) {
+                     errorMessage = vokabelnReader.errorMessage();
+                 }
             }
             break;
 
             case Csv: {
                 qDebug() << "Reading CVS document...";
-                qCritical ("CVS document not yet supported...");
-                errorMessage = "CVS document not yet supported...";
-//                 QmVocCsvReader csvReader( f );
-//                 read = csvReader.readDoc( this );
-//                 if ( !read ) {
-//                     errorMessage = csvReader.errorMessage();
-//                 }
+//                qCritical ("CVS document not yet supported...");
+//                errorMessage = "CVS document not yet supported...";
+                 QmVocCsvReader csvReader( f );
+                 read = csvReader.readDoc( this );
+                 if ( !read ) {
+                     errorMessage = csvReader.errorMessage();
+                 }
             }
             break;
 
